==> sinosun-ui-0.3.1.tgz: package/es/datetime-picker/index.js <==
import DatetimePickerView from '../datetime-picker-view';
import Popup from "../popup";
import TransferDom from '../directives/transfer-dom';
import { dateFormat } from '../utils/dateUtil';
import { zeroComplete } from '../utils/numberUtil';
import "./index.less";

var DatetimePicker = {
    name: "DatetimePicker",
    data: function data() {
        return {
            show: false,
            forceUpdate: false,
            currentValue: ''
        };
    },

    directives: { TransferDom: TransferDom },
    props: {
        value: [String, Number, Array, Date],
        readonly: Boolean,
        mode: {
            type: String,
            'default': 'date'
        },
        displayFormat: {
            type: String,
            'default': 'YYYY/MM/DD'
        },
        disabledDate: Function,
        vertical: {
            type: Boolean,
            'default': true
        }
    },
    computed: {
        formatValue: function formatValue() {
            var mode = this.mode,
                currentValue = this.currentValue;

            if (mode === 'date') {
                return dateFormat(currentValue, this.displayFormat);
            } else if (mode === 'datetime') {
                if (this.displayFormat.indexOf('HH:mm') > 0) {
                    return dateFormat(currentValue, this.displayFormat);
                } else {
                    return dateFormat(currentValue, this.displayFormat + ' HH:mm');
                }
            } else if (mode === 'year-month') {
                if (currentValue instanceof Array) {
                    if (currentValue.length === 1) {
                        return zeroComplete(currentValue[0]) + '-' + zeroComplete(new Date().getMonth() + 1);
                    } else if (currentValue.length === 2) {
                        return zeroComplete(currentValue[0]) + '-' + zeroComplete(currentValue[1]);
                    } else {
                        console.error("[sinosun-ui] DatetimePicker 'year-month'模式下参数只能为包含1个或2个的数组");
                    }
                } else {
                    console.error("[sinosun-ui] DatetimePicker 'year-month'模式下参数只能为数组");
                }
            } else if (mode === 'year' || mode === 'month') {
                if (currentValue instanceof Array) {
                    if (currentValue.length === 1) {
                        return '' + zeroComplete(currentValue[0]);
                    } else {
                        console.error("[sinosun-ui] DatetimePicker 'year-month'模式下参数只能为包含1个或2个的数组");
                    }
                } else {
                    console.error("[sinosun-ui] DatetimePicker 'year'或者'month'模式下参数只能为数组");
                }
            } else if (mode === 'time') {
                if (currentValue instanceof Array) {
                    if (currentValue.length === 1) {
                        return zeroComplete(currentValue[0]) + ':' + zeroComplete(new Date().getMinutes());
                    } else if (currentValue.length === 2) {
                        return zeroComplete(currentValue[0]) + ':' + zeroComplete(currentValue[1]);
                    } else {
                        console.error("[sinosun-ui] DatetimePicker 'time'模式下参数只能为包含1个或2个的数组");
                    }
                } else {
                    console.error("[sinosun-ui] DatetimePicker 'time'模式下参数只能为数组");
                }
            } else {
                console.error("[sinosun-ui] DatetimePicker 'mode'模式不是有效模式");
            }
        }
    },
    created: function created() {
        this.currentValue = this.value || new Date();
    },
    mounted: function mounted() {},

    methods: {
        onInput: function onInput(val) {
            this.show = val;
        },
        onShow: function onShow() {
            this.$emit('show');
        },
        onHide: function onHide() {
            var _this = this;

            this.show = false;
            this.$emit('hide');

            setTimeout(function () {
                _this.forceUpdate = false;
            }, 150);
        },
        onClick: function onClick() {
            if (!this.readonly) {
                this.show = true;
                this.forceUpdate = true;
            }
        },
        onChange: function onChange(val) {
            var _this2 = this;

            if (!this.$listeners['change']) {
                this.$emit('input', val);
            }

            this.show = false;
            setTimeout(function () {
                _this2.forceUpdate = false;
            }, 150);
            this.$emit('change', val);
        }
    },
    watch: {
        value: function value(newVal, oldVal) {
            this.currentValue = newVal;
        }
    },
    render: function render() {
        var h = arguments[0];
        var currentValue = this.currentValue,
            formatValue = this.formatValue,
            forceUpdate = this.forceUpdate,
            show = this.show,
            mode = this.mode,
            disabledDate = this.disabledDate,
            vertical = this.vertical;


        return h(
            'div',
            { 'class': 'sn-datetime-picker', on: {
                    'click': this.onClick
                }
            },
            [h(
                'span',
                { 'class': 'sn-datetime-picker-value' },
                [formatValue]
            ), h(
                'div',
                {
                    directives: [{
                        name: 'transfer-dom',
                        value: true
                    }]
                },
                [h(
                    Popup,
                    {
                        attrs: { value: show },
                        on: {
                            'input': this.onInput,
                            'click-overlay': this.onHide
                        },
                        style: 'background: transparent;' },
                    [forceUpdate ? h(
                        'div',
                        { 'class': 'sn-datetime-picker-content' },
                        [h(DatetimePickerView, {
                            attrs: {
                                value: currentValue,
                                mode: mode,
                                disabledDate: disabledDate,
                                vertical: vertical
                            },
                            on: {
                                'change': this.onChange
                            }
                        })]
                    ) : null]
                )]
            )]
        );
    }
};

export default DatetimePicker;

==> sinosun-ui-0.3.6.tgz: package/es/datetime-picker/index.js <==
import DatetimePickerView from '../datetime-picker-view';
import Popup from "../popup";
import TransferDom from '../directives/transfer-dom';
import { dateFormat } from '../utils/dateUtil';
import { zeroComplete } from '../utils/numberUtil';
import "./index.less";

var DatetimePicker = {
    name: "DatetimePicker",
    data: function data() {
        return {
            show: false,
            forceUpdate: false,
            currentValue: ''
        };
    },

    directives: { TransferDom: TransferDom },
    props: {
        value: [String, Number, Array, Date],
        readonly: Boolean,
        mode: {
            type: String,
            'default': 'date'
        },
        displayFormat: {
            type: String,
            'default': 'YYYY/MM/DD'
        },
        disabledDate: Function,
        vertical: {
            type: Boolean,
            'default': true
        },
        minuteStep: [String, Number]
    },
    computed: {
        formatValue: function formatValue() {
            var mode = this.mode,
                currentValue = this.currentValue;

            if (mode === 'date') {
                return dateFormat(currentValue, this.displayFormat);
            } else if (mode === 'datetime') {
                if (this.displayFormat.indexOf('HH:mm') > 0) {
                    return dateFormat(currentValue, this.displayFormat);
                } else {
                    return dateFormat(currentValue, this.displayFormat + ' HH:mm');
                }
            } else if (mode === 'year-month') {
                if (currentValue instanceof Array) {
                    if (currentValue.length === 0) {
                        return zeroComplete(new Date().getFullYear()) + '-' + zeroComplete(new Date().getMonth() + 1);
                    } else if (currentValue.length === 1) {
                        return zeroComplete(currentValue[0]) + '-' + zeroComplete(new Date().getMonth() + 1);
                    } else if (currentValue.length === 2) {
                        return zeroComplete(currentValue[0]) + '-' + zeroComplete(currentValue[1]);
                    } else {
                        console.error("[sinosun-ui] DatetimePicker 'year-month'模式下参数最多为2个的数组");
                    }
                } else {
                    console.error("[sinosun-ui] DatetimePicker 'year-month'模式下参数只能为数组");
                }
            } else if (mode === 'year' || mode === 'month') {
                if (currentValue instanceof Array) {
                    if (currentValue.length === 1) {
                        return '' + zeroComplete(currentValue[0]);
                    } else {
                        console.error("[sinosun-ui] DatetimePicker 'year-month'模式下参数只能为包含1个或2个的数组");
                    }
                } else {
                    console.error("[sinosun-ui] DatetimePicker 'year'或者'month'模式下参数只能为数组");
                }
            } else if (mode === 'time') {
                if (currentValue instanceof Array) {
                    if (currentValue.length === 1) {
                        return zeroComplete(currentValue[0]) + ':' + zeroComplete(new Date().getMinutes());
                    } else if (currentValue.length === 2) {
                        return zeroComplete(currentValue[0]) + ':' + zeroComplete(currentValue[1]);
                    } else {
                        console.error("[sinosun-ui] DatetimePicker 'time'模式下参数只能为包含1个或2个的数组");
                    }
                } else {
                    console.error("[sinosun-ui] DatetimePicker 'time'模式下参数只能为数组");
                }
            } else {
                console.error("[sinosun-ui] DatetimePicker 'mode'模式不是有效模式");
            }
        }
    },
    created: function created() {
        this.currentValue = this.value || new Date();
    },
    mounted: function mounted() {},

    methods: {
        onInput: function onInput(val) {
            this.show = val;
        },
        onViewInput: function onViewInput(val) {
            var _this = this;

            this.show = false;
            setTimeout(function () {
                _this.forceUpdate = false;
            }, 150);

            if (this.$listeners['change']) {
                this.$emit('change', val);
            } else {
                this.$emit('input', val);
            }
        },
        onShow: function onShow() {
            this.$emit('show');
        },
        onHide: function onHide() {
            var _this2 = this;

            this.show = false;
            this.$emit('hide');

            setTimeout(function () {
                _this2.forceUpdate = false;
            }, 150);
        },
        onClick: function onClick() {
            if (!this.readonly) {
                this.show = true;
                this.forceUpdate = true;
            }
        },
        onChange: function onChange(val) {
            this.$emit('value-change', val);
        }
    },
    watch: {
        value: function value(newVal, oldVal) {
            this.currentValue = newVal;
        }
    },
    render: function render() {
        var h = arguments[0];
        var currentValue = this.currentValue,
            formatValue = this.formatValue,
            forceUpdate = this.forceUpdate,
            show = this.show,
            mode = this.mode,
            disabledDate = this.disabledDate,
            vertical = this.vertical,
            minuteStep = this.minuteStep;


        return h(
            'div',
            { 'class': 'sn-datetime-picker', on: {
                    'click': this.onClick
                }
            },
            [h(
                'span',
                { 'class': 'sn-datetime-picker-value' },
                [formatValue]
            ), h(
                'div',
                {
                    directives: [{
                        name: 'transfer-dom',
                        value: true
                    }]
                },
                [h(
                    Popup,
                    {
                        attrs: { value: show },
                        on: {
                            'input': this.onInput,
                            'click-overlay': this.onHide
                        },
                        style: 'background: transparent;' },
                    [forceUpdate ? h(
                        'div',
                        { 'class': 'sn-datetime-picker-content' },
                        [h(DatetimePickerView, {
                            attrs: {
                                value: currentValue,
                                mode: mode,
                                disabledDate: disabledDate,
                                vertical: vertical,
                                minuteStep: minuteStep
                            },
                            on: {
                                'input': this.onViewInput,
                                'change': this.onChange
                            }
                        })]
                    ) : null]
                )]
            )]
        );
    }
};

export default DatetimePicker;
